==> AmaterasUML_1.1.2.zip: src/net/java/amateras/uml/model/AbstractUMLEntityModel.java <==
package net.java.amateras.uml.model;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import net.java.amateras.uml.classdiagram.model.AttributeModel;
import net.java.amateras.uml.classdiagram.model.OperationModel;

import org.eclipse.draw2d.geometry.Rectangle;
import org.eclipse.swt.graphics.RGB;

public abstract class AbstractUMLEntityModel extends AbstractUMLModel {
	
	private Rectangle constraint;
	// ̃fLтĂRlNṼXg
	private List sourceConnections = new ArrayList();
	// ̃fɌĒĂRlNṼXg
	private List targetConnections = new ArrayList();
	
	private List children = new ArrayList();
	
	public static final String P_CONSTRAINT = "_constraint";
	public static final String P_SOURCE_CONNECTION = "_source_connection";
	public static final String P_TARGET_CONNECTION = "_target_connection";
	public static final String P_CHILDREN = "_children";
		
	public Rectangle getConstraint() {
		return constraint;
	}
	
	public void addChild(Object obj) {
		children.add(obj);
	}
	
	public void removeChild(Object obj) {
		children.remove(obj);
	}
	
	public void addOperation(OperationModel model){
		this.children.add(model);
		firePropertyChange(P_CHILDREN,null,model);
	}
	
	public void addAttribute(AttributeModel model){
		this.children.add(model);
		firePropertyChange(P_CHILDREN,null,model);
	}
	
	public void removeOperation(OperationModel model){
		this.children.remove(model);
		firePropertyChange(P_CHILDREN,null,model);
	}
	
	public void removeAttribute(AttributeModel model){
		this.children.remove(model);
		firePropertyChange(P_CHILDREN,null,model);
	}
	
	public List getChildren(){
		return this.children;
	}
	
	public void setConstraint(Rectangle constraint) {
		this.constraint = constraint;
		firePropertyChange(P_CONSTRAINT, null, constraint);
	}
	
	/** ̃foRlNV f̒ǉ */
	public void addSourceConnection(Object connx) {
		sourceConnections.add(connx);
		firePropertyChange(P_SOURCE_CONNECTION, null, connx);
	}
	
	/** ̃fɐڑRlNV f̒ǉ */
	public void addTargetConnection(Object connx) {
		targetConnections.add(connx);
		firePropertyChange(P_TARGET_CONNECTION, null, connx);
	}
	
	/** ̃fڑƂRlNṼXgԂ */
	public List getModelSourceConnections() {
		return sourceConnections;
	}
	
	/** ̃fڑƂRlNṼXgԂ */
	public List getModelTargetConnections() {
		return targetConnections;
	}
	
	/** ̃fRlNṼ\[X؂藣 */
	public void removeSourceConnection(Object connx) {
		sourceConnections.remove(connx);
		firePropertyChange(P_SOURCE_CONNECTION, connx, null);
	}
	
	/** ̃fRlNṼ^[Qbg؂藣 */
	public void removeTargetConnection(Object connx) {
		targetConnections.remove(connx);
		firePropertyChange(P_TARGET_CONNECTION, connx, null);
	}
	
	public void setBackgroundColor(RGB backgroundColor) {
		for (Iterator iter = children.iterator(); iter.hasNext();) {
			AbstractUMLModel element = (AbstractUMLModel) iter.next();
			element.setBackgroundColor(backgroundColor);
		}
		super.setBackgroundColor(backgroundColor);
	}
	
	public void setForegroundColor(RGB foregroundColor) {
		for (Iterator iter = children.iterator(); iter.hasNext();) {
			AbstractUMLModel element = (AbstractUMLModel) iter.next();
			element.setForegroundColor(foregroundColor);
		}
		super.setForegroundColor(foregroundColor);
	}
	
	public void setShowIcon(boolean showIcon) {
		for (Iterator iter = children.iterator(); iter.hasNext();) {
			AbstractUMLModel element = (AbstractUMLModel) iter.next();
			element.setShowIcon(showIcon);
		}
		super.setShowIcon(showIcon);
	}
}

==> AmaterasUML_1.2.1.zip: src/net/java/amateras/uml/model/AbstractUMLEntityModel.java <==
package net.java.amateras.uml.model;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import org.eclipse.draw2d.geometry.Rectangle;
import org.eclipse.swt.graphics.RGB;

public abstract class AbstractUMLEntityModel extends AbstractUMLModel {
	
	private Rectangle constraint;
	// ̃fLтĂRlNṼXg
	private List sourceConnections = new ArrayList();
	// ̃fɌĒĂRlNṼXg
	private List targetConnections = new ArrayList();
	
	private List children = new ArrayList();
	//flags of show/hide property
	private Map filterProperty = new HashMap();
		
	public static final String P_CONSTRAINT = "_constraint";
	public static final String P_SOURCE_CONNECTION = "_source_connection";
	public static final String P_TARGET_CONNECTION = "_target_connection";
	public static final String P_CHILDREN = "_children";
	public static final String P_FILTER = "_filter";
	public static final String P_FORCE_UPDATE = "_force_update";
	
	public Map getFilterProperty() {
		return filterProperty;
	}
	
	public void setFilterProperty(Map filterProperty) {
		this.filterProperty = filterProperty;
		firePropertyChange(P_FILTER, null, filterProperty);
	}
	
	public Rectangle getConstraint() {
		return constraint;
	}
	
	public void addChild(AbstractUMLModel model) {
		children.add(model);
		model.setParent(this);
		firePropertyChange(P_CHILDREN,null,model);
	}
	
	public void removeChild(AbstractUMLModel model) {
		children.remove(model);
		model.setParent(this);
		firePropertyChange(P_CHILDREN,null,model);
	}
	
	public void forceUpdate() {
		firePropertyChange(P_FORCE_UPDATE, null ,null);
	}

	public List getChildren(){
		return this.children;
	}
	
	public void setConstraint(Rectangle constraint) {
		this.constraint = constraint;
		firePropertyChange(P_CONSTRAINT, null, constraint);
	}
	
	/** ̃foRlNV f̒ǉ */
	public void addSourceConnection(Object connx) {
		sourceConnections.add(connx);
		firePropertyChange(P_SOURCE_CONNECTION, null, connx);
	}
	
	/** ̃fɐڑRlNV f̒ǉ */
	public void addTargetConnection(Object connx) {
		targetConnections.add(connx);
		firePropertyChange(P_TARGET_CONNECTION, null, connx);
	}
	
	/** ̃fڑƂRlNṼXgԂ */
	public List getModelSourceConnections() {
		return sourceConnections;
	}
	
	/** ̃fڑƂRlNṼXgԂ */
	public List getModelTargetConnections() {
		return targetConnections;
	}
	
	/** ̃fRlNṼ\[X؂藣 */
	public void removeSourceConnection(Object connx) {
		sourceConnections.remove(connx);
		firePropertyChange(P_SOURCE_CONNECTION, connx, null);
	}
	
	/** ̃fRlNṼ^[Qbg؂藣 */
	public void removeTargetConnection(Object connx) {
		targetConnections.remove(connx);
		firePropertyChange(P_TARGET_CONNECTION, connx, null);
	}
	
	public void setBackgroundColor(RGB backgroundColor) {
		for (Iterator iter = children.iterator(); iter.hasNext();) {
			AbstractUMLModel element = (AbstractUMLModel) iter.next();
			element.setBackgroundColor(backgroundColor);
		}
		super.setBackgroundColor(backgroundColor);
	}
	
	public void setForegroundColor(RGB foregroundColor) {
		for (Iterator iter = children.iterator(); iter.hasNext();) {
			AbstractUMLModel element = (AbstractUMLModel) iter.next();
			element.setForegroundColor(foregroundColor);
		}
		super.setForegroundColor(foregroundColor);
	}
	
	public void setShowIcon(boolean showIcon) {
		for (Iterator iter = children.iterator(); iter.hasNext();) {
			AbstractUMLModel element = (AbstractUMLModel) iter.next();
			element.setShowIcon(showIcon);
		}
		super.setShowIcon(showIcon);
	}
}
